# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from grid.protos.grid.v1 import whoami_pb2 as grid_dot_v1_dot_whoami__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/events.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14grid/v1/events.proto\x12\x07grid.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14grid/v1/whoami.proto\"\xef\x02\n\x05\x45vent\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x1f\n\x0bresource_id\x18\x03 \x01(\tR\nresourceId\x12#\n\rresource_name\x18\x04 \x01(\tR\x0cresourceName\x12:\n\rresource_type\x18\x05 \x01(\x0e\x32\x15.grid.v1.ResourceTypeR\x0cresourceType\x12\x17\n\x07user_id\x18\x06 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x07 \x01(\tR\tclusterId\x12\x31\n\nevent_type\x18\x08 \x01(\x0e\x32\x12.grid.v1.EventTypeR\teventType\x12/\n\x06\x63\x61ller\x18\t \x01(\x0b\x32\x17.grid.v1.WhoAmIResponseR\x06\x63\x61ller*o\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x45VENT_TYPE_CREATED\x10\x01\x12\x16\n\x12\x45VENT_TYPE_UPDATED\x10\x02\x12\x16\n\x12\x45VENT_TYPE_DELETED\x10\x03*\xbd\x01\n\x0cResourceType\x12\x1d\n\x19RESOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18RESOURCE_TYPE_EXPERIMENT\x10\x01\x12\x19\n\x15RESOURCE_TYPE_SESSION\x10\x02\x12\x1b\n\x17RESOURCE_TYPE_DATASTORE\x10\x03\x12\x1d\n\x19RESOURCE_TYPE_TENSORBOARD\x10\x04\x12\x19\n\x15RESOURCE_TYPE_CLUSTER\x10\x05\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,grid_dot_v1_dot_whoami__pb2.DESCRIPTOR,])

_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='grid.v1.EventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EVENT_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_TYPE_CREATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_TYPE_UPDATED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_TYPE_DELETED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=458,
  serialized_end=569,
)
_sym_db.RegisterEnumDescriptor(_EVENTTYPE)

EventType = enum_type_wrapper.EnumTypeWrapper(_EVENTTYPE)
_RESOURCETYPE = _descriptor.EnumDescriptor(
  name='ResourceType',
  full_name='grid.v1.ResourceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_TYPE_EXPERIMENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_TYPE_SESSION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_TYPE_DATASTORE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_TYPE_TENSORBOARD', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_TYPE_CLUSTER', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=572,
  serialized_end=761,
)
_sym_db.RegisterEnumDescriptor(_RESOURCETYPE)

ResourceType = enum_type_wrapper.EnumTypeWrapper(_RESOURCETYPE)
EVENT_TYPE_UNSPECIFIED = 0
EVENT_TYPE_CREATED = 1
EVENT_TYPE_UPDATED = 2
EVENT_TYPE_DELETED = 3
RESOURCE_TYPE_UNSPECIFIED = 0
RESOURCE_TYPE_EXPERIMENT = 1
RESOURCE_TYPE_SESSION = 2
RESOURCE_TYPE_DATASTORE = 3
RESOURCE_TYPE_TENSORBOARD = 4
RESOURCE_TYPE_CLUSTER = 5



_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='grid.v1.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.Event.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='grid.v1.Event.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='grid.v1.Event.resource_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='grid.v1.Event.resource_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='grid.v1.Event.resource_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.Event.user_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.Event.cluster_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='grid.v1.Event.event_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='eventType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caller', full_name='grid.v1.Event.caller', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='caller', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=456,
)

_EVENT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENT.fields_by_name['resource_type'].enum_type = _RESOURCETYPE
_EVENT.fields_by_name['event_type'].enum_type = _EVENTTYPE
_EVENT.fields_by_name['caller'].message_type = grid_dot_v1_dot_whoami__pb2._WHOAMIRESPONSE
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.enum_types_by_name['EventType'] = _EVENTTYPE
DESCRIPTOR.enum_types_by_name['ResourceType'] = _RESOURCETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'grid.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.Event)
  })
_sym_db.RegisterMessage(Event)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import sshpublickey_service_pb2 as grid_dot_v1_dot_sshpublickey__service__pb2


class SSHPublicKeyServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateSSHPublicKey = channel.unary_unary(
        '/grid.v1.SSHPublicKeyService/CreateSSHPublicKey',
        request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.CreateSSHPublicKeyRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.CreateSSHPublicKeyResponse.FromString,
        )
    self.GetSSHPublicKey = channel.unary_unary(
        '/grid.v1.SSHPublicKeyService/GetSSHPublicKey',
        request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.GetSSHPublicKeyRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.GetSSHPublicKeyResponse.FromString,
        )
    self.ListSSHPublicKeys = channel.unary_unary(
        '/grid.v1.SSHPublicKeyService/ListSSHPublicKeys',
        request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.ListSSHPublicKeysRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.ListSSHPublicKeysResponse.FromString,
        )
    self.UpdateSSHPublicKey = channel.unary_unary(
        '/grid.v1.SSHPublicKeyService/UpdateSSHPublicKey',
        request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyResponse.FromString,
        )
    self.UpdateSSHPublicKeyStatus = channel.unary_unary(
        '/grid.v1.SSHPublicKeyService/UpdateSSHPublicKeyStatus',
        request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyStatusRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyStatusResponse.FromString,
        )
    self.DeleteSSHPublicKey = channel.unary_unary(
        '/grid.v1.SSHPublicKeyService/DeleteSSHPublicKey',
        request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.DeleteSSHPublicKeyRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.DeleteSSHPublicKeyResponse.FromString,
        )
    self.WatchSSHPublicKeys = channel.unary_stream(
        '/grid.v1.SSHPublicKeyService/WatchSSHPublicKeys',
        request_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.WatchSSHPublicKeysRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.WatchSSHPublicKeysResponse.FromString,
        )


class SSHPublicKeyServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateSSHPublicKey(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetSSHPublicKey(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListSSHPublicKeys(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateSSHPublicKey(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateSSHPublicKeyStatus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteSSHPublicKey(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WatchSSHPublicKeys(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SSHPublicKeyServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateSSHPublicKey': grpc.unary_unary_rpc_method_handler(
          servicer.CreateSSHPublicKey,
          request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.CreateSSHPublicKeyRequest.FromString,
          response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.CreateSSHPublicKeyResponse.SerializeToString,
      ),
      'GetSSHPublicKey': grpc.unary_unary_rpc_method_handler(
          servicer.GetSSHPublicKey,
          request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.GetSSHPublicKeyRequest.FromString,
          response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.GetSSHPublicKeyResponse.SerializeToString,
      ),
      'ListSSHPublicKeys': grpc.unary_unary_rpc_method_handler(
          servicer.ListSSHPublicKeys,
          request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.ListSSHPublicKeysRequest.FromString,
          response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.ListSSHPublicKeysResponse.SerializeToString,
      ),
      'UpdateSSHPublicKey': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateSSHPublicKey,
          request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyRequest.FromString,
          response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyResponse.SerializeToString,
      ),
      'UpdateSSHPublicKeyStatus': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateSSHPublicKeyStatus,
          request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyStatusRequest.FromString,
          response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.UpdateSSHPublicKeyStatusResponse.SerializeToString,
      ),
      'DeleteSSHPublicKey': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteSSHPublicKey,
          request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.DeleteSSHPublicKeyRequest.FromString,
          response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.DeleteSSHPublicKeyResponse.SerializeToString,
      ),
      'WatchSSHPublicKeys': grpc.unary_stream_rpc_method_handler(
          servicer.WatchSSHPublicKeys,
          request_deserializer=grid_dot_v1_dot_sshpublickey__service__pb2.WatchSSHPublicKeysRequest.FromString,
          response_serializer=grid_dot_v1_dot_sshpublickey__service__pb2.WatchSSHPublicKeysResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'grid.v1.SSHPublicKeyService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# coding: utf-8

# flake8: noqa
"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from grid.openapi.models.body import Body
from grid.openapi.models.body1 import Body1
from grid.openapi.models.body2 import Body2
from grid.openapi.models.body3 import Body3
from grid.openapi.models.body4 import Body4
from grid.openapi.models.body5 import Body5
from grid.openapi.models.body6 import Body6
from grid.openapi.models.externalv1_cluster import Externalv1Cluster
from grid.openapi.models.externalv1_create_cluster_request import Externalv1CreateClusterRequest
from grid.openapi.models.externalv1_create_cluster_response import Externalv1CreateClusterResponse
from grid.openapi.models.externalv1_create_session_request import Externalv1CreateSessionRequest
from grid.openapi.models.externalv1_create_session_response import Externalv1CreateSessionResponse
from grid.openapi.models.externalv1_create_tensorboard_response import Externalv1CreateTensorboardResponse
from grid.openapi.models.externalv1_datastore import Externalv1Datastore
from grid.openapi.models.externalv1_datastore_spec import Externalv1DatastoreSpec
from grid.openapi.models.externalv1_datastore_status import Externalv1DatastoreStatus
from grid.openapi.models.externalv1_delete_cluster_response import Externalv1DeleteClusterResponse
from grid.openapi.models.externalv1_delete_session_response import Externalv1DeleteSessionResponse
from grid.openapi.models.externalv1_delete_tensorboard_response import Externalv1DeleteTensorboardResponse
from grid.openapi.models.externalv1_get_session_response import Externalv1GetSessionResponse
from grid.openapi.models.externalv1_get_tensorboard_response import Externalv1GetTensorboardResponse
from grid.openapi.models.externalv1_list_clusters_response import Externalv1ListClustersResponse
from grid.openapi.models.externalv1_list_sessions_response import Externalv1ListSessionsResponse
from grid.openapi.models.externalv1_list_tensorboards_response import Externalv1ListTensorboardsResponse
from grid.openapi.models.externalv1_session import Externalv1Session
from grid.openapi.models.externalv1_tensorboard import Externalv1Tensorboard
from grid.openapi.models.externalv1_update_cluster_response import Externalv1UpdateClusterResponse
from grid.openapi.models.externalv1_update_session_response import Externalv1UpdateSessionResponse
from grid.openapi.models.externalv1_update_tensorboard_response import Externalv1UpdateTensorboardResponse
from grid.openapi.models.protobuf_any import ProtobufAny
from grid.openapi.models.rpc_status import RpcStatus
from grid.openapi.models.v1_aws_cluster_driver_spec import V1AWSClusterDriverSpec
from grid.openapi.models.v1_azure_cluster_driver_spec import V1AzureClusterDriverSpec
from grid.openapi.models.v1_azure_cluster_driver_status import V1AzureClusterDriverStatus
from grid.openapi.models.v1_cluster_driver import V1ClusterDriver
from grid.openapi.models.v1_cluster_driver_status import V1ClusterDriverStatus
from grid.openapi.models.v1_cluster_performance_profile import V1ClusterPerformanceProfile
from grid.openapi.models.v1_cluster_spec import V1ClusterSpec
from grid.openapi.models.v1_cluster_state import V1ClusterState
from grid.openapi.models.v1_cluster_status import V1ClusterStatus
from grid.openapi.models.v1_cluster_type import V1ClusterType
from grid.openapi.models.v1_complete_datastore_presigned_urls_upload_response import V1CompleteDatastorePresignedUrlsUploadResponse
from grid.openapi.models.v1_complete_presigned_url_upload import V1CompletePresignedUrlUpload
from grid.openapi.models.v1_create_datastore_presigned_urls_response import V1CreateDatastorePresignedUrlsResponse
from grid.openapi.models.v1_create_datastore_request import V1CreateDatastoreRequest
from grid.openapi.models.v1_create_datastore_response import V1CreateDatastoreResponse
from grid.openapi.models.v1_create_saml_organization_request import V1CreateSamlOrganizationRequest
from grid.openapi.models.v1_create_saml_organization_response import V1CreateSamlOrganizationResponse
from grid.openapi.models.v1_datastore_input import V1DatastoreInput
from grid.openapi.models.v1_datastore_optimization_status import V1DatastoreOptimizationStatus
from grid.openapi.models.v1_delete_datastore_response import V1DeleteDatastoreResponse
from grid.openapi.models.v1_delete_saml_organization_response import V1DeleteSamlOrganizationResponse
from grid.openapi.models.v1_eks_custer_driver_status import V1EKSCusterDriverStatus
from grid.openapi.models.v1_external_kubeconfig import V1ExternalKubeconfig
from grid.openapi.models.v1_get_datastore_response import V1GetDatastoreResponse
from grid.openapi.models.v1_instance_spec import V1InstanceSpec
from grid.openapi.models.v1_instance_type import V1InstanceType
from grid.openapi.models.v1_kubernetes_cluster_driver import V1KubernetesClusterDriver
from grid.openapi.models.v1_kubernetes_cluster_status import V1KubernetesClusterStatus
from grid.openapi.models.v1_list_cluster_instance_types_response import V1ListClusterInstanceTypesResponse
from grid.openapi.models.v1_list_datastores_response import V1ListDatastoresResponse
from grid.openapi.models.v1_list_saml_organizations_response import V1ListSamlOrganizationsResponse
from grid.openapi.models.v1_login_request import V1LoginRequest
from grid.openapi.models.v1_login_response import V1LoginResponse
from grid.openapi.models.v1_logout_request import V1LogoutRequest
from grid.openapi.models.v1_logout_response import V1LogoutResponse
from grid.openapi.models.v1_presigned_upload_url import V1PresignedUploadUrl
from grid.openapi.models.v1_refresh_request import V1RefreshRequest
from grid.openapi.models.v1_refresh_response import V1RefreshResponse
from grid.openapi.models.v1_resources import V1Resources
from grid.openapi.models.v1_saml_organization import V1SamlOrganization
from grid.openapi.models.v1_saml_organization_status import V1SamlOrganizationStatus
from grid.openapi.models.v1_session_spec import V1SessionSpec
from grid.openapi.models.v1_session_state import V1SessionState
from grid.openapi.models.v1_session_status import V1SessionStatus
from grid.openapi.models.v1_slurm_cluster_driver import V1SlurmClusterDriver
from grid.openapi.models.v1_slurm_cluster_status import V1SlurmClusterStatus
from grid.openapi.models.v1_tensorboard_experiment_config import V1TensorboardExperimentConfig
from grid.openapi.models.v1_tensorboard_spec import V1TensorboardSpec
from grid.openapi.models.v1_tensorboard_state import V1TensorboardState
from grid.openapi.models.v1_tensorboard_status import V1TensorboardStatus
from grid.openapi.models.v1_update_datastore_response import V1UpdateDatastoreResponse



# coding: utf-8

"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from grid.openapi.api_client import ApiClient


class TensorboardServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def tensorboard_service_create_tensorboard(self, cluster_id, body, **kwargs):  # noqa: E501
        """tensorboard_service_create_tensorboard  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tensorboard_service_create_tensorboard(cluster_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cluster_id: (required)
        :param Body4 body: (required)
        :return: Externalv1CreateTensorboardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tensorboard_service_create_tensorboard_with_http_info(cluster_id, body, **kwargs)  # noqa: E501
        else:
            (data) = self.tensorboard_service_create_tensorboard_with_http_info(cluster_id, body, **kwargs)  # noqa: E501
            return data

    def tensorboard_service_create_tensorboard_with_http_info(self, cluster_id, body, **kwargs):  # noqa: E501
        """tensorboard_service_create_tensorboard  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tensorboard_service_create_tensorboard_with_http_info(cluster_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cluster_id: (required)
        :param Body4 body: (required)
        :return: Externalv1CreateTensorboardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cluster_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tensorboard_service_create_tensorboard" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cluster_id' is set
        if self.api_client.client_side_validation and ('cluster_id' not in params or
                                                       params['cluster_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cluster_id` when calling `tensorboard_service_create_tensorboard`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `tensorboard_service_create_tensorboard`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_id' in params:
            path_params['clusterId'] = params['cluster_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/core/{clusterId}/tensorboards', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Externalv1CreateTensorboardResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tensorboard_service_delete_tensorboard(self, cluster_id, id, **kwargs):  # noqa: E501
        """tensorboard_service_delete_tensorboard  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tensorboard_service_delete_tensorboard(cluster_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cluster_id: (required)
        :param str id: (required)
        :return: Externalv1DeleteTensorboardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tensorboard_service_delete_tensorboard_with_http_info(cluster_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.tensorboard_service_delete_tensorboard_with_http_info(cluster_id, id, **kwargs)  # noqa: E501
            return data

    def tensorboard_service_delete_tensorboard_with_http_info(self, cluster_id, id, **kwargs):  # noqa: E501
        """tensorboard_service_delete_tensorboard  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tensorboard_service_delete_tensorboard_with_http_info(cluster_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cluster_id: (required)
        :param str id: (required)
        :return: Externalv1DeleteTensorboardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cluster_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tensorboard_service_delete_tensorboard" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cluster_id' is set
        if self.api_client.client_side_validation and ('cluster_id' not in params or
                                                       params['cluster_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cluster_id` when calling `tensorboard_service_delete_tensorboard`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `tensorboard_service_delete_tensorboard`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_id' in params:
            path_params['clusterId'] = params['cluster_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/core/{clusterId}/tensorboards/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Externalv1DeleteTensorboardResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tensorboard_service_get_tensorboard(self, cluster_id, id, **kwargs):  # noqa: E501
        """tensorboard_service_get_tensorboard  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tensorboard_service_get_tensorboard(cluster_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cluster_id: (required)
        :param str id: (required)
        :return: Externalv1GetTensorboardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tensorboard_service_get_tensorboard_with_http_info(cluster_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.tensorboard_service_get_tensorboard_with_http_info(cluster_id, id, **kwargs)  # noqa: E501
            return data

    def tensorboard_service_get_tensorboard_with_http_info(self, cluster_id, id, **kwargs):  # noqa: E501
        """tensorboard_service_get_tensorboard  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tensorboard_service_get_tensorboard_with_http_info(cluster_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cluster_id: (required)
        :param str id: (required)
        :return: Externalv1GetTensorboardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cluster_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tensorboard_service_get_tensorboard" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cluster_id' is set
        if self.api_client.client_side_validation and ('cluster_id' not in params or
                                                       params['cluster_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cluster_id` when calling `tensorboard_service_get_tensorboard`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `tensorboard_service_get_tensorboard`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_id' in params:
            path_params['clusterId'] = params['cluster_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/core/{clusterId}/tensorboards/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Externalv1GetTensorboardResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tensorboard_service_list_tensorboards(self, cluster_id, **kwargs):  # noqa: E501
        """tensorboard_service_list_tensorboards  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tensorboard_service_list_tensorboards(cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cluster_id: (required)
        :param str page_token:
        :param str limit:
        :param list[str] user_ids:
        :param datetime created_before:
        :param list[str] phase_in:
        :param list[str] phase_not_in:
        :return: Externalv1ListTensorboardsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tensorboard_service_list_tensorboards_with_http_info(cluster_id, **kwargs)  # noqa: E501
        else:
            (data) = self.tensorboard_service_list_tensorboards_with_http_info(cluster_id, **kwargs)  # noqa: E501
            return data

    def tensorboard_service_list_tensorboards_with_http_info(self, cluster_id, **kwargs):  # noqa: E501
        """tensorboard_service_list_tensorboards  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tensorboard_service_list_tensorboards_with_http_info(cluster_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cluster_id: (required)
        :param str page_token:
        :param str limit:
        :param list[str] user_ids:
        :param datetime created_before:
        :param list[str] phase_in:
        :param list[str] phase_not_in:
        :return: Externalv1ListTensorboardsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cluster_id', 'page_token', 'limit', 'user_ids', 'created_before', 'phase_in', 'phase_not_in']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tensorboard_service_list_tensorboards" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cluster_id' is set
        if self.api_client.client_side_validation and ('cluster_id' not in params or
                                                       params['cluster_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cluster_id` when calling `tensorboard_service_list_tensorboards`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_id' in params:
            path_params['clusterId'] = params['cluster_id']  # noqa: E501

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'user_ids' in params:
            query_params.append(('userIds', params['user_ids']))  # noqa: E501
            collection_formats['userIds'] = 'multi'  # noqa: E501
        if 'created_before' in params:
            query_params.append(('createdBefore', params['created_before']))  # noqa: E501
        if 'phase_in' in params:
            query_params.append(('phaseIn', params['phase_in']))  # noqa: E501
            collection_formats['phaseIn'] = 'multi'  # noqa: E501
        if 'phase_not_in' in params:
            query_params.append(('phaseNotIn', params['phase_not_in']))  # noqa: E501
            collection_formats['phaseNotIn'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/core/{clusterId}/tensorboards', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Externalv1ListTensorboardsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tensorboard_service_update_tensorboard(self, cluster_id, id, body, **kwargs):  # noqa: E501
        """tensorboard_service_update_tensorboard  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tensorboard_service_update_tensorboard(cluster_id, id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cluster_id: (required)
        :param str id: (required)
        :param Body5 body: (required)
        :return: Externalv1UpdateTensorboardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tensorboard_service_update_tensorboard_with_http_info(cluster_id, id, body, **kwargs)  # noqa: E501
        else:
            (data) = self.tensorboard_service_update_tensorboard_with_http_info(cluster_id, id, body, **kwargs)  # noqa: E501
            return data

    def tensorboard_service_update_tensorboard_with_http_info(self, cluster_id, id, body, **kwargs):  # noqa: E501
        """tensorboard_service_update_tensorboard  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tensorboard_service_update_tensorboard_with_http_info(cluster_id, id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cluster_id: (required)
        :param str id: (required)
        :param Body5 body: (required)
        :return: Externalv1UpdateTensorboardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cluster_id', 'id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tensorboard_service_update_tensorboard" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cluster_id' is set
        if self.api_client.client_side_validation and ('cluster_id' not in params or
                                                       params['cluster_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cluster_id` when calling `tensorboard_service_update_tensorboard`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `tensorboard_service_update_tensorboard`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `tensorboard_service_update_tensorboard`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_id' in params:
            path_params['clusterId'] = params['cluster_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/core/{clusterId}/tensorboards/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Externalv1UpdateTensorboardResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import cluster_service_pb2 as grid_dot_v1_dot_cluster__service__pb2


class ClusterServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateCluster = channel.unary_unary(
        '/grid.v1.ClusterService/CreateCluster',
        request_serializer=grid_dot_v1_dot_cluster__service__pb2.CreateClusterRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_cluster__service__pb2.CreateClusterResponse.FromString,
        )
    self.GetCluster = channel.unary_unary(
        '/grid.v1.ClusterService/GetCluster',
        request_serializer=grid_dot_v1_dot_cluster__service__pb2.GetClusterRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_cluster__service__pb2.GetClusterResponse.FromString,
        )
    self.ListClusters = channel.unary_unary(
        '/grid.v1.ClusterService/ListClusters',
        request_serializer=grid_dot_v1_dot_cluster__service__pb2.ListClustersRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_cluster__service__pb2.ListClustersResponse.FromString,
        )
    self.UpdateCluster = channel.unary_unary(
        '/grid.v1.ClusterService/UpdateCluster',
        request_serializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterResponse.FromString,
        )
    self.UpdateClusterStatus = channel.unary_unary(
        '/grid.v1.ClusterService/UpdateClusterStatus',
        request_serializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterStatusRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterStatusResponse.FromString,
        )
    self.DeleteCluster = channel.unary_unary(
        '/grid.v1.ClusterService/DeleteCluster',
        request_serializer=grid_dot_v1_dot_cluster__service__pb2.DeleteClusterRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_cluster__service__pb2.DeleteClusterResponse.FromString,
        )
    self.WatchClusters = channel.unary_stream(
        '/grid.v1.ClusterService/WatchClusters',
        request_serializer=grid_dot_v1_dot_cluster__service__pb2.WatchClustersRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_cluster__service__pb2.WatchClustersResponse.FromString,
        )
    self.QueryClusterLogs = channel.unary_unary(
        '/grid.v1.ClusterService/QueryClusterLogs',
        request_serializer=grid_dot_v1_dot_cluster__service__pb2.QueryClusterLogsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_cluster__service__pb2.QueryClusterLogsResponse.FromString,
        )
    self.TailClusterLogs = channel.unary_stream(
        '/grid.v1.ClusterService/TailClusterLogs',
        request_serializer=grid_dot_v1_dot_cluster__service__pb2.TailClusterLogsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_cluster__service__pb2.TailClusterLogsResponse.FromString,
        )


class ClusterServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateCluster(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetCluster(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListClusters(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateCluster(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateClusterStatus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteCluster(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WatchClusters(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def QueryClusterLogs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def TailClusterLogs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ClusterServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateCluster': grpc.unary_unary_rpc_method_handler(
          servicer.CreateCluster,
          request_deserializer=grid_dot_v1_dot_cluster__service__pb2.CreateClusterRequest.FromString,
          response_serializer=grid_dot_v1_dot_cluster__service__pb2.CreateClusterResponse.SerializeToString,
      ),
      'GetCluster': grpc.unary_unary_rpc_method_handler(
          servicer.GetCluster,
          request_deserializer=grid_dot_v1_dot_cluster__service__pb2.GetClusterRequest.FromString,
          response_serializer=grid_dot_v1_dot_cluster__service__pb2.GetClusterResponse.SerializeToString,
      ),
      'ListClusters': grpc.unary_unary_rpc_method_handler(
          servicer.ListClusters,
          request_deserializer=grid_dot_v1_dot_cluster__service__pb2.ListClustersRequest.FromString,
          response_serializer=grid_dot_v1_dot_cluster__service__pb2.ListClustersResponse.SerializeToString,
      ),
      'UpdateCluster': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateCluster,
          request_deserializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterRequest.FromString,
          response_serializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterResponse.SerializeToString,
      ),
      'UpdateClusterStatus': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateClusterStatus,
          request_deserializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterStatusRequest.FromString,
          response_serializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterStatusResponse.SerializeToString,
      ),
      'DeleteCluster': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteCluster,
          request_deserializer=grid_dot_v1_dot_cluster__service__pb2.DeleteClusterRequest.FromString,
          response_serializer=grid_dot_v1_dot_cluster__service__pb2.DeleteClusterResponse.SerializeToString,
      ),
      'WatchClusters': grpc.unary_stream_rpc_method_handler(
          servicer.WatchClusters,
          request_deserializer=grid_dot_v1_dot_cluster__service__pb2.WatchClustersRequest.FromString,
          response_serializer=grid_dot_v1_dot_cluster__service__pb2.WatchClustersResponse.SerializeToString,
      ),
      'QueryClusterLogs': grpc.unary_unary_rpc_method_handler(
          servicer.QueryClusterLogs,
          request_deserializer=grid_dot_v1_dot_cluster__service__pb2.QueryClusterLogsRequest.FromString,
          response_serializer=grid_dot_v1_dot_cluster__service__pb2.QueryClusterLogsResponse.SerializeToString,
      ),
      'TailClusterLogs': grpc.unary_stream_rpc_method_handler(
          servicer.TailClusterLogs,
          request_deserializer=grid_dot_v1_dot_cluster__service__pb2.TailClusterLogsRequest.FromString,
          response_serializer=grid_dot_v1_dot_cluster__service__pb2.TailClusterLogsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'grid.v1.ClusterService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/user.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12grid/v1/user.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x92\x01\n\x04User\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12.\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32\x14.grid.v1.UserDetailsR\x07\x64\x65tails\x12+\n\x06status\x18\x03 \x01(\x0b\x32\x13.grid.v1.UserStatusR\x06status\"\x9b\x03\n\x0bUserDetails\x12#\n\rauth_provider\x18\x01 \x01(\tR\x0c\x61uthProvider\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\x12\x1d\n\nfirst_name\x18\x03 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x04 \x01(\tR\x08lastName\x12\x14\n\x05\x65mail\x18\x05 \x01(\tR\x05\x65mail\x12*\n\x08\x61pi_keys\x18\x06 \x03(\x0b\x32\x0f.grid.v1.ApiKeyR\x07\x61piKeys\x12\x1f\n\x0bpicture_url\x18\x07 \x01(\tR\npictureUrl\x12\x1a\n\x08internal\x18\x0b \x01(\x08R\x08internal\x12!\n\x0cphone_number\x18\x0c \x01(\tR\x0bphoneNumber\x12\x31\n\x08\x66\x65\x61tures\x18\r \x01(\x0b\x32\x15.grid.v1.UserFeaturesR\x08\x66\x65\x61tures\x12:\n\x0bpreferences\x18\x0e \x01(\x0b\x32\x18.grid.v1.UserPreferencesR\x0bpreferences\"1\n\x0cUserFeatures\x12!\n\x0c\x62yoc_enabled\x18\x01 \x01(\x08R\x0b\x62yocEnabled\"?\n\x0fUserPreferences\x12,\n\x12\x64\x65\x66\x61ult_cluster_id\x18\x02 \x01(\tR\x10\x64\x65\x66\x61ultClusterId\"\xca\x01\n\x06\x41piKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12#\n\rsecret_sha256\x18\x02 \x01(\x0cR\x0csecretSha256\x12\x39\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x37\n\tlast_used\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08lastUsed\x12\x17\n\x07raw_key\x18\x05 \x01(\tR\x06rawKey\"\xa5\x01\n\x12VerificationStatus\x12\x1f\n\x0bis_verified\x18\x01 \x01(\x08R\nisVerified\x12\x31\n\x14verification_channel\x18\x02 \x01(\tR\x13verificationChannel\x12;\n\x0bverified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nverifiedAt\"\xec\x01\n\nUserStatus\x12%\n\x0einstalled_grid\x18\x01 \x01(\x08R\rinstalledGrid\x12)\n\x10\x63ompleted_signup\x18\x02 \x01(\x08R\x0f\x63ompletedSignup\x12\x1f\n\x0b\x63li_version\x18\x03 \x01(\tR\ncliVersion\x12\x1d\n\nis_blocked\x18\x04 \x01(\x08R\tisBlocked\x12L\n\x13verification_status\x18\x05 \x01(\x0b\x32\x1b.grid.v1.VerificationStatusR\x12verificationStatusB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_USER = _descriptor.Descriptor(
  name='User',
  full_name='grid.v1.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='grid.v1.User.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='grid.v1.User.details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='details', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='grid.v1.User.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=235,
)


_USERDETAILS = _descriptor.Descriptor(
  name='UserDetails',
  full_name='grid.v1.UserDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_provider', full_name='grid.v1.UserDetails.auth_provider', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='authProvider', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='grid.v1.UserDetails.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='username', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='grid.v1.UserDetails.first_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='firstName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='grid.v1.UserDetails.last_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lastName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='grid.v1.UserDetails.email', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='email', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='api_keys', full_name='grid.v1.UserDetails.api_keys', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='apiKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='picture_url', full_name='grid.v1.UserDetails.picture_url', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pictureUrl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal', full_name='grid.v1.UserDetails.internal', index=7,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='internal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='grid.v1.UserDetails.phone_number', index=8,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phoneNumber', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='grid.v1.UserDetails.features', index=9,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='features', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferences', full_name='grid.v1.UserDetails.preferences', index=10,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='preferences', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=649,
)


_USERFEATURES = _descriptor.Descriptor(
  name='UserFeatures',
  full_name='grid.v1.UserFeatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='byoc_enabled', full_name='grid.v1.UserFeatures.byoc_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='byocEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=700,
)


_USERPREFERENCES = _descriptor.Descriptor(
  name='UserPreferences',
  full_name='grid.v1.UserPreferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_cluster_id', full_name='grid.v1.UserPreferences.default_cluster_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='defaultClusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=702,
  serialized_end=765,
)


_APIKEY = _descriptor.Descriptor(
  name='ApiKey',
  full_name='grid.v1.ApiKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.ApiKey.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret_sha256', full_name='grid.v1.ApiKey.secret_sha256', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='secretSha256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='grid.v1.ApiKey.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='createdAt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_used', full_name='grid.v1.ApiKey.last_used', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lastUsed', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_key', full_name='grid.v1.ApiKey.raw_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=768,
  serialized_end=970,
)


_VERIFICATIONSTATUS = _descriptor.Descriptor(
  name='VerificationStatus',
  full_name='grid.v1.VerificationStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_verified', full_name='grid.v1.VerificationStatus.is_verified', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isVerified', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verification_channel', full_name='grid.v1.VerificationStatus.verification_channel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='verificationChannel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verified_at', full_name='grid.v1.VerificationStatus.verified_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='verifiedAt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=973,
  serialized_end=1138,
)


_USERSTATUS = _descriptor.Descriptor(
  name='UserStatus',
  full_name='grid.v1.UserStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='installed_grid', full_name='grid.v1.UserStatus.installed_grid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='installedGrid', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='completed_signup', full_name='grid.v1.UserStatus.completed_signup', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='completedSignup', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cli_version', full_name='grid.v1.UserStatus.cli_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cliVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_blocked', full_name='grid.v1.UserStatus.is_blocked', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isBlocked', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verification_status', full_name='grid.v1.UserStatus.verification_status', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='verificationStatus', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1141,
  serialized_end=1377,
)

_USER.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
_USER.fields_by_name['details'].message_type = _USERDETAILS
_USER.fields_by_name['status'].message_type = _USERSTATUS
_USERDETAILS.fields_by_name['api_keys'].message_type = _APIKEY
_USERDETAILS.fields_by_name['features'].message_type = _USERFEATURES
_USERDETAILS.fields_by_name['preferences'].message_type = _USERPREFERENCES
_APIKEY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_APIKEY.fields_by_name['last_used'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VERIFICATIONSTATUS.fields_by_name['verified_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_USERSTATUS.fields_by_name['verification_status'].message_type = _VERIFICATIONSTATUS
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['UserDetails'] = _USERDETAILS
DESCRIPTOR.message_types_by_name['UserFeatures'] = _USERFEATURES
DESCRIPTOR.message_types_by_name['UserPreferences'] = _USERPREFERENCES
DESCRIPTOR.message_types_by_name['ApiKey'] = _APIKEY
DESCRIPTOR.message_types_by_name['VerificationStatus'] = _VERIFICATIONSTATUS
DESCRIPTOR.message_types_by_name['UserStatus'] = _USERSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'grid.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.User)
  })
_sym_db.RegisterMessage(User)

UserDetails = _reflection.GeneratedProtocolMessageType('UserDetails', (_message.Message,), {
  'DESCRIPTOR' : _USERDETAILS,
  '__module__' : 'grid.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UserDetails)
  })
_sym_db.RegisterMessage(UserDetails)

UserFeatures = _reflection.GeneratedProtocolMessageType('UserFeatures', (_message.Message,), {
  'DESCRIPTOR' : _USERFEATURES,
  '__module__' : 'grid.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UserFeatures)
  })
_sym_db.RegisterMessage(UserFeatures)

UserPreferences = _reflection.GeneratedProtocolMessageType('UserPreferences', (_message.Message,), {
  'DESCRIPTOR' : _USERPREFERENCES,
  '__module__' : 'grid.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UserPreferences)
  })
_sym_db.RegisterMessage(UserPreferences)

ApiKey = _reflection.GeneratedProtocolMessageType('ApiKey', (_message.Message,), {
  'DESCRIPTOR' : _APIKEY,
  '__module__' : 'grid.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ApiKey)
  })
_sym_db.RegisterMessage(ApiKey)

VerificationStatus = _reflection.GeneratedProtocolMessageType('VerificationStatus', (_message.Message,), {
  'DESCRIPTOR' : _VERIFICATIONSTATUS,
  '__module__' : 'grid.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.VerificationStatus)
  })
_sym_db.RegisterMessage(VerificationStatus)

UserStatus = _reflection.GeneratedProtocolMessageType('UserStatus', (_message.Message,), {
  'DESCRIPTOR' : _USERSTATUS,
  '__module__' : 'grid.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UserStatus)
  })
_sym_db.RegisterMessage(UserStatus)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import event_service_pb2 as grid_dot_v1_dot_event__service__pb2


class EventServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetEvents = channel.unary_unary(
        '/grid.v1.EventService/GetEvents',
        request_serializer=grid_dot_v1_dot_event__service__pb2.GetEventsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_event__service__pb2.GetEventsResponse.FromString,
        )
    self.WatchEvents = channel.unary_stream(
        '/grid.v1.EventService/WatchEvents',
        request_serializer=grid_dot_v1_dot_event__service__pb2.WatchEventsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_event__service__pb2.WatchEventsResponse.FromString,
        )


class EventServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetEvents(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WatchEvents(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_EventServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetEvents': grpc.unary_unary_rpc_method_handler(
          servicer.GetEvents,
          request_deserializer=grid_dot_v1_dot_event__service__pb2.GetEventsRequest.FromString,
          response_serializer=grid_dot_v1_dot_event__service__pb2.GetEventsResponse.SerializeToString,
      ),
      'WatchEvents': grpc.unary_stream_rpc_method_handler(
          servicer.WatchEvents,
          request_deserializer=grid_dot_v1_dot_event__service__pb2.WatchEventsRequest.FromString,
          response_serializer=grid_dot_v1_dot_event__service__pb2.WatchEventsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'grid.v1.EventService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from dataclasses import dataclass
import datetime
from typing import Dict

from grid.sdk.user import User


@dataclass(frozen=True)
class Team:
    team_id: str
    name: str
    created_at: datetime.datetime
    role: str
    members: Dict[str, User]



from typing import Callable, Optional, Tuple

import arrow
import click
from google.protobuf.timestamp_pb2 import Timestamp

from grid.cli.exceptions import LogLimitExceeded
from grid.protos.grid.v1.cluster_service_pb2 import (
    QueryClusterLogsRequest,
    QueryClusterLogsResponse,
    TailClusterLogsRequest,
    TailClusterLogsResponse,
)
from grid.protos.grid.v1.cluster_service_pb2_grpc import ClusterServiceStub
from grid.protos.grid.v1.logs_pb2 import LogEntry


def arrow_to_timestamp_pb2(timestamp: arrow.Arrow, add_nanos: int = 0) -> Timestamp:
    sol = Timestamp()
    sol.FromDatetime(timestamp.datetime)
    sol.nanos += add_nanos
    return sol


def fancy_log_writer(
    time_format: str,
    component: Optional[str] = None,
) -> Callable[[LogEntry], None]:
    def f(log_entry: LogEntry):
        timestamp = arrow.get(log_entry.timestamp.ToDatetime())
        if time_format == "human":
            timestamp_part = click.style("{:>15}".format(timestamp.humanize()), fg='green')
        elif time_format == "iso8601":
            timestamp_part = click.style(str(timestamp), fg='green')
        else:
            raise click.ClickException(f"Unknown time format: got {time_format}, valid entries: [human,iso8601]")

        component_part = click.style(component, fg='magenta')
        message_part = log_entry.message.rstrip()
        if component:
            click.echo(f"[{timestamp_part}]: {message_part}")
        else:
            click.echo(f"[{component_part}] [{timestamp_part}]: {message_part}")

    return f


async def _query_range(
    cluster_id: str,
    from_time: Timestamp,
    to_time: Timestamp,
    limit: int,
    per_query_limit: int,
    cluster_service: ClusterServiceStub,
    log_writer: Callable[[LogEntry], None],
) -> Tuple[int, Timestamp]:
    currently_fetched = 0
    while currently_fetched < limit:
        resp: QueryClusterLogsResponse = await cluster_service.QueryClusterLogs(
            QueryClusterLogsRequest(
                cluster_id=cluster_id,
                limit=min(per_query_limit, limit - currently_fetched),
                start_timestamp=from_time,
                end_timestamp=to_time,
            )
        )

        for entry in resp.entries:
            entry: LogEntry
            from_time.CopyFrom(entry.timestamp)
            from_time.nanos += 1
            log_writer(entry)

        currently_fetched += len(resp.entries)
        if len(resp.entries) < per_query_limit:
            return currently_fetched, from_time
    else:
        raise LogLimitExceeded()


async def _tail_logs(
    cluster_id: str,
    from_time: Timestamp,
    limit: int,
    cluster_service: ClusterServiceStub,
    log_writer: Callable[[LogEntry], None],
):
    if limit <= 0:
        raise LogLimitExceeded()
    async for resp in cluster_service.TailClusterLogs(
        TailClusterLogsRequest(
            cluster_id=cluster_id,
            limit=limit,
            start_timestamp=from_time,
        )
    ):
        resp: TailClusterLogsResponse
        for entry in resp.entries:
            entry: LogEntry
            limit -= 1
            log_writer(entry)
        if limit <= 0:
            raise LogLimitExceeded()


async def cluster_logs(
    cluster_id: str,
    tail: bool,
    from_time: arrow.Arrow,
    to_time: arrow.Arrow,
    limit: int,
    max_per_query_limit: int,
    cluster_service: ClusterServiceStub,
    log_writer: Callable[[LogEntry], None],
):
    per_query_limit = min(limit, max_per_query_limit)
    from_time_timestampb2 = arrow_to_timestamp_pb2(from_time)
    to_time_timestamppb2 = arrow_to_timestamp_pb2(to_time)

    currently_fetched, from_time_timestampb2 = await _query_range(
        cluster_id=cluster_id,
        from_time=from_time_timestampb2,
        to_time=to_time_timestamppb2,
        limit=limit,
        per_query_limit=per_query_limit,
        cluster_service=cluster_service,
        log_writer=log_writer,
    )
    if tail:
        await _tail_logs(
            cluster_id=cluster_id,
            from_time=from_time_timestampb2,
            limit=limit - currently_fetched,
            cluster_service=cluster_service,
            log_writer=log_writer,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/experiment_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import event_pb2 as grid_dot_v1_dot_event__pb2
from grid.protos.grid.v1 import experiment_pb2 as grid_dot_v1_dot_experiment__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/experiment_service.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n grid/v1/experiment_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x13grid/v1/event.proto\x1a\x18grid/v1/experiment.proto\"N\n\x17\x43reateExperimentRequest\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"O\n\x18\x43reateExperimentResponse\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"&\n\x14GetExperimentRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"L\n\x15GetExperimentResponse\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"\xc0\x02\n\x16ListExperimentsRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x15\n\x06run_id\x18\x04 \x01(\tR\x05runId\x12\x17\n\x07user_id\x18\x05 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x06 \x01(\tR\tclusterId\x12\x33\n\x08phase_in\x18\x07 \x03(\x0e\x32\x18.grid.v1.ExperimentStateR\x07phaseIn\x12:\n\x0cphase_not_in\x18\x08 \x03(\x0e\x32\x18.grid.v1.ExperimentStateR\nphaseNotIn\"\xa0\x01\n\x17ListExperimentsResponse\x12\x33\n\nexperiment\x18\x01 \x03(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"N\n\x17UpdateExperimentRequest\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"O\n\x18UpdateExperimentResponse\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"T\n\x1dUpdateExperimentStatusRequest\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"U\n\x1eUpdateExperimentStatusResponse\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"N\n\x17\x44\x65leteExperimentRequest\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"O\n\x18\x44\x65leteExperimentResponse\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment\"\x9a\x02\n\x17WatchExperimentsRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x15\n\x06run_id\x18\x04 \x01(\tR\x05runId\x12\x17\n\x07user_id\x18\x05 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x06 \x01(\tR\tclusterId\x12\x33\n\x08phase_in\x18\x07 \x03(\x0e\x32\x18.grid.v1.ExperimentStateR\x07phaseIn\x12:\n\x0cphase_not_in\x18\x08 \x03(\x0e\x32\x18.grid.v1.ExperimentStateR\nphaseNotIn\"\xa2\x01\n\x18WatchExperimentsResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x12.grid.v1.EventTypeR\x04type\x12\x33\n\nexperiment\x18\x03 \x01(\x0b\x32\x13.grid.v1.ExperimentR\nexperiment2\x94\x05\n\x11\x45xperimentService\x12Y\n\x10\x43reateExperiment\x12 .grid.v1.CreateExperimentRequest\x1a!.grid.v1.CreateExperimentResponse\"\x00\x12P\n\rGetExperiment\x12\x1d.grid.v1.GetExperimentRequest\x1a\x1e.grid.v1.GetExperimentResponse\"\x00\x12V\n\x0fListExperiments\x12\x1f.grid.v1.ListExperimentsRequest\x1a .grid.v1.ListExperimentsResponse\"\x00\x12Y\n\x10UpdateExperiment\x12 .grid.v1.UpdateExperimentRequest\x1a!.grid.v1.UpdateExperimentResponse\"\x00\x12i\n\x16UpdateExperimentStatus\x12&.grid.v1.UpdateExperimentStatusRequest\x1a\'.grid.v1.UpdateExperimentStatusResponse\x12Y\n\x10\x44\x65leteExperiment\x12 .grid.v1.DeleteExperimentRequest\x1a!.grid.v1.DeleteExperimentResponse\"\x00\x12Y\n\x10WatchExperiments\x12 .grid.v1.WatchExperimentsRequest\x1a!.grid.v1.WatchExperimentsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,grid_dot_v1_dot_event__pb2.DESCRIPTOR,grid_dot_v1_dot_experiment__pb2.DESCRIPTOR,])




_CREATEEXPERIMENTREQUEST = _descriptor.Descriptor(
  name='CreateExperimentRequest',
  full_name='grid.v1.CreateExperimentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='grid.v1.CreateExperimentRequest.experiment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experiment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=224,
)


_CREATEEXPERIMENTRESPONSE = _descriptor.Descriptor(
  name='CreateExperimentResponse',
  full_name='grid.v1.CreateExperimentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='grid.v1.CreateExperimentResponse.experiment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experiment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=305,
)


_GETEXPERIMENTREQUEST = _descriptor.Descriptor(
  name='GetExperimentRequest',
  full_name='grid.v1.GetExperimentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.GetExperimentRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=307,
  serialized_end=345,
)


_GETEXPERIMENTRESPONSE = _descriptor.Descriptor(
  name='GetExperimentResponse',
  full_name='grid.v1.GetExperimentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='grid.v1.GetExperimentResponse.experiment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experiment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=423,
)


_LISTEXPERIMENTSREQUEST = _descriptor.Descriptor(
  name='ListExperimentsRequest',
  full_name='grid.v1.ListExperimentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListExperimentsRequest.continue_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListExperimentsRequest.resource_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.ListExperimentsRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_id', full_name='grid.v1.ListExperimentsRequest.run_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='runId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.ListExperimentsRequest.user_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.ListExperimentsRequest.cluster_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_in', full_name='grid.v1.ListExperimentsRequest.phase_in', index=6,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_not_in', full_name='grid.v1.ListExperimentsRequest.phase_not_in', index=7,
      number=8, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseNotIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=746,
)


_LISTEXPERIMENTSRESPONSE = _descriptor.Descriptor(
  name='ListExperimentsResponse',
  full_name='grid.v1.ListExperimentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='grid.v1.ListExperimentsResponse.experiment', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experiment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListExperimentsResponse.continue_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListExperimentsResponse.resource_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=749,
  serialized_end=909,
)


_UPDATEEXPERIMENTREQUEST = _descriptor.Descriptor(
  name='UpdateExperimentRequest',
  full_name='grid.v1.UpdateExperimentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='grid.v1.UpdateExperimentRequest.experiment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experiment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=911,
  serialized_end=989,
)


_UPDATEEXPERIMENTRESPONSE = _descriptor.Descriptor(
  name='UpdateExperimentResponse',
  full_name='grid.v1.UpdateExperimentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='grid.v1.UpdateExperimentResponse.experiment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experiment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=991,
  serialized_end=1070,
)


_UPDATEEXPERIMENTSTATUSREQUEST = _descriptor.Descriptor(
  name='UpdateExperimentStatusRequest',
  full_name='grid.v1.UpdateExperimentStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='grid.v1.UpdateExperimentStatusRequest.experiment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experiment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1072,
  serialized_end=1156,
)


_UPDATEEXPERIMENTSTATUSRESPONSE = _descriptor.Descriptor(
  name='UpdateExperimentStatusResponse',
  full_name='grid.v1.UpdateExperimentStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='grid.v1.UpdateExperimentStatusResponse.experiment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experiment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1158,
  serialized_end=1243,
)


_DELETEEXPERIMENTREQUEST = _descriptor.Descriptor(
  name='DeleteExperimentRequest',
  full_name='grid.v1.DeleteExperimentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='grid.v1.DeleteExperimentRequest.experiment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experiment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1245,
  serialized_end=1323,
)


_DELETEEXPERIMENTRESPONSE = _descriptor.Descriptor(
  name='DeleteExperimentResponse',
  full_name='grid.v1.DeleteExperimentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='grid.v1.DeleteExperimentResponse.experiment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experiment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1325,
  serialized_end=1404,
)


_WATCHEXPERIMENTSREQUEST = _descriptor.Descriptor(
  name='WatchExperimentsRequest',
  full_name='grid.v1.WatchExperimentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchExperimentsRequest.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.WatchExperimentsRequest.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_id', full_name='grid.v1.WatchExperimentsRequest.run_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='runId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.WatchExperimentsRequest.user_id', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.WatchExperimentsRequest.cluster_id', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_in', full_name='grid.v1.WatchExperimentsRequest.phase_in', index=5,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_not_in', full_name='grid.v1.WatchExperimentsRequest.phase_not_in', index=6,
      number=8, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseNotIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1407,
  serialized_end=1689,
)


_WATCHEXPERIMENTSRESPONSE = _descriptor.Descriptor(
  name='WatchExperimentsResponse',
  full_name='grid.v1.WatchExperimentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchExperimentsResponse.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='grid.v1.WatchExperimentsResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experiment', full_name='grid.v1.WatchExperimentsResponse.experiment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experiment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1692,
  serialized_end=1854,
)

_CREATEEXPERIMENTREQUEST.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_CREATEEXPERIMENTRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_GETEXPERIMENTRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_LISTEXPERIMENTSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENTSTATE
_LISTEXPERIMENTSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENTSTATE
_LISTEXPERIMENTSRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_UPDATEEXPERIMENTREQUEST.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_UPDATEEXPERIMENTRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_UPDATEEXPERIMENTSTATUSREQUEST.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_UPDATEEXPERIMENTSTATUSRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_DELETEEXPERIMENTREQUEST.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_DELETEEXPERIMENTRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_WATCHEXPERIMENTSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENTSTATE
_WATCHEXPERIMENTSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENTSTATE
_WATCHEXPERIMENTSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_event__pb2._EVENTTYPE
_WATCHEXPERIMENTSRESPONSE.fields_by_name['experiment'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
DESCRIPTOR.message_types_by_name['CreateExperimentRequest'] = _CREATEEXPERIMENTREQUEST
DESCRIPTOR.message_types_by_name['CreateExperimentResponse'] = _CREATEEXPERIMENTRESPONSE
DESCRIPTOR.message_types_by_name['GetExperimentRequest'] = _GETEXPERIMENTREQUEST
DESCRIPTOR.message_types_by_name['GetExperimentResponse'] = _GETEXPERIMENTRESPONSE
DESCRIPTOR.message_types_by_name['ListExperimentsRequest'] = _LISTEXPERIMENTSREQUEST
DESCRIPTOR.message_types_by_name['ListExperimentsResponse'] = _LISTEXPERIMENTSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateExperimentRequest'] = _UPDATEEXPERIMENTREQUEST
DESCRIPTOR.message_types_by_name['UpdateExperimentResponse'] = _UPDATEEXPERIMENTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateExperimentStatusRequest'] = _UPDATEEXPERIMENTSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateExperimentStatusResponse'] = _UPDATEEXPERIMENTSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteExperimentRequest'] = _DELETEEXPERIMENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteExperimentResponse'] = _DELETEEXPERIMENTRESPONSE
DESCRIPTOR.message_types_by_name['WatchExperimentsRequest'] = _WATCHEXPERIMENTSREQUEST
DESCRIPTOR.message_types_by_name['WatchExperimentsResponse'] = _WATCHEXPERIMENTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateExperimentRequest = _reflection.GeneratedProtocolMessageType('CreateExperimentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEXPERIMENTREQUEST,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateExperimentRequest)
  })
_sym_db.RegisterMessage(CreateExperimentRequest)

CreateExperimentResponse = _reflection.GeneratedProtocolMessageType('CreateExperimentResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEXPERIMENTRESPONSE,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateExperimentResponse)
  })
_sym_db.RegisterMessage(CreateExperimentResponse)

GetExperimentRequest = _reflection.GeneratedProtocolMessageType('GetExperimentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEXPERIMENTREQUEST,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetExperimentRequest)
  })
_sym_db.RegisterMessage(GetExperimentRequest)

GetExperimentResponse = _reflection.GeneratedProtocolMessageType('GetExperimentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEXPERIMENTRESPONSE,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetExperimentResponse)
  })
_sym_db.RegisterMessage(GetExperimentResponse)

ListExperimentsRequest = _reflection.GeneratedProtocolMessageType('ListExperimentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXPERIMENTSREQUEST,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListExperimentsRequest)
  })
_sym_db.RegisterMessage(ListExperimentsRequest)

ListExperimentsResponse = _reflection.GeneratedProtocolMessageType('ListExperimentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXPERIMENTSRESPONSE,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListExperimentsResponse)
  })
_sym_db.RegisterMessage(ListExperimentsResponse)

UpdateExperimentRequest = _reflection.GeneratedProtocolMessageType('UpdateExperimentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEXPERIMENTREQUEST,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateExperimentRequest)
  })
_sym_db.RegisterMessage(UpdateExperimentRequest)

UpdateExperimentResponse = _reflection.GeneratedProtocolMessageType('UpdateExperimentResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEXPERIMENTRESPONSE,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateExperimentResponse)
  })
_sym_db.RegisterMessage(UpdateExperimentResponse)

UpdateExperimentStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateExperimentStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEXPERIMENTSTATUSREQUEST,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateExperimentStatusRequest)
  })
_sym_db.RegisterMessage(UpdateExperimentStatusRequest)

UpdateExperimentStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateExperimentStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEXPERIMENTSTATUSRESPONSE,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateExperimentStatusResponse)
  })
_sym_db.RegisterMessage(UpdateExperimentStatusResponse)

DeleteExperimentRequest = _reflection.GeneratedProtocolMessageType('DeleteExperimentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEEXPERIMENTREQUEST,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteExperimentRequest)
  })
_sym_db.RegisterMessage(DeleteExperimentRequest)

DeleteExperimentResponse = _reflection.GeneratedProtocolMessageType('DeleteExperimentResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEEXPERIMENTRESPONSE,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteExperimentResponse)
  })
_sym_db.RegisterMessage(DeleteExperimentResponse)

WatchExperimentsRequest = _reflection.GeneratedProtocolMessageType('WatchExperimentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHEXPERIMENTSREQUEST,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchExperimentsRequest)
  })
_sym_db.RegisterMessage(WatchExperimentsRequest)

WatchExperimentsResponse = _reflection.GeneratedProtocolMessageType('WatchExperimentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHEXPERIMENTSRESPONSE,
  '__module__' : 'grid.v1.experiment_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchExperimentsResponse)
  })
_sym_db.RegisterMessage(WatchExperimentsResponse)


DESCRIPTOR._options = None

_EXPERIMENTSERVICE = _descriptor.ServiceDescriptor(
  name='ExperimentService',
  full_name='grid.v1.ExperimentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1857,
  serialized_end=2517,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateExperiment',
    full_name='grid.v1.ExperimentService.CreateExperiment',
    index=0,
    containing_service=None,
    input_type=_CREATEEXPERIMENTREQUEST,
    output_type=_CREATEEXPERIMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExperiment',
    full_name='grid.v1.ExperimentService.GetExperiment',
    index=1,
    containing_service=None,
    input_type=_GETEXPERIMENTREQUEST,
    output_type=_GETEXPERIMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListExperiments',
    full_name='grid.v1.ExperimentService.ListExperiments',
    index=2,
    containing_service=None,
    input_type=_LISTEXPERIMENTSREQUEST,
    output_type=_LISTEXPERIMENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateExperiment',
    full_name='grid.v1.ExperimentService.UpdateExperiment',
    index=3,
    containing_service=None,
    input_type=_UPDATEEXPERIMENTREQUEST,
    output_type=_UPDATEEXPERIMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateExperimentStatus',
    full_name='grid.v1.ExperimentService.UpdateExperimentStatus',
    index=4,
    containing_service=None,
    input_type=_UPDATEEXPERIMENTSTATUSREQUEST,
    output_type=_UPDATEEXPERIMENTSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteExperiment',
    full_name='grid.v1.ExperimentService.DeleteExperiment',
    index=5,
    containing_service=None,
    input_type=_DELETEEXPERIMENTREQUEST,
    output_type=_DELETEEXPERIMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchExperiments',
    full_name='grid.v1.ExperimentService.WatchExperiments',
    index=6,
    containing_service=None,
    input_type=_WATCHEXPERIMENTSREQUEST,
    output_type=_WATCHEXPERIMENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXPERIMENTSERVICE)

DESCRIPTOR.services_by_name['ExperimentService'] = _EXPERIMENTSERVICE

# @@protoc_insertion_point(module_scope)
